
/*
 * Copyright (c) 1998 Kevan Stannard. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL or COMMERCIAL purposes and
 * without fee is hereby granted. 
 * 
 * Please note that this software comes with
 * NO WARRANTY 
 *
 * BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED
 * BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
 * PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS
 * TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME
 * THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION. 
 * 
 * IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER
 * PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
 * INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
 * THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED
 * BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER
 * OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 */

/**
 * Matrix2D is a standard two dimensional matrix object with associated matrix arithmetic.
 * Only double data types supported.
 *
 * @version 1.0
 * @author  Kevan Stannard
 */

class Matrix2D extends Object
{
	private int cols;			// num columns
	private int rows;			// num rows
	public double element[][];	// the data element

	public Matrix2D()
	{
		this(3,3);
	}

	public Matrix2D(int rows, int cols)
	{
		this.cols = cols;
		this.rows = rows;
		element = new double[rows][cols];
		makeIdentity();
	}

	public int getCols()
	{
		return cols;
	}

	public int getRows()
	{
		return rows;
	}

	public void makeIdentity()
	{
		for (int r=0; r<rows; r++)
		{
			for (int c=0; c<cols; c++)
			{
				if (r==c)
				{
					element[r][c] = 1;
				}
				else
				{
					element[r][c] = 0;
				}
			}
		}
	}

	public String toString()
	{
		String str = "";

		for (int r=0; r<rows; r++)
		{
			str += '[';
			for (int c=0; c<cols; c++)
			{
				str += element[r][c];
				if (c<cols-1)
				{
					str += ',';
				}
			}
			str += ']';
		}

		return str;
	}

	public void setElement(int r, int c, double value)
	{
		if (r>=0 && r<rows && c>=0 && c<cols)
		{
			element[r][c] = value;
		}
	}

	public double getElement(int r, int c)
	{
		if (r>=0 && r<rows && c>=0 && c<cols)
		{
			return element[r][c];
		}

		return 0;
	}
}
