
/*
 * Copyright (c) 1998 Kevan Stannard. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL or COMMERCIAL purposes and
 * without fee is hereby granted. 
 * 
 * Please note that this software comes with
 * NO WARRANTY 
 *
 * BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED
 * BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
 * PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS
 * TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME
 * THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION. 
 * 
 * IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER
 * PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
 * INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
 * THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED
 * BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER
 * OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 */

import java.awt.*;

/**
 * Object3D defines a set of vertices which form a trivial 3d object
 *
 * @version 1.0
 * @author  Kevan Stannard
 */

class Object3D extends Object
{
	int maxVertices;
	int numVertices;
	Vertex vertices[];

	double x;	// x position in 3d space 
	double y;	// y position in 3d space
	double z;	// z position in 3d space

	//
	// rotation matrices
	//

	Matrix2D xRotationMatrix;
	Matrix2D yRotationMatrix;
	Matrix2D zRotationMatrix;

	public Object3D()
	{
		this(3000);
	}

	public Object3D(int maxVertices)
	{
		//
		// initialise vertices
		//

		this.maxVertices = maxVertices;
		vertices = new Vertex[maxVertices];
		numVertices = 0;

		//
		// set object coordinate at origin
		//

		x = y = z = 0;

	}

	public String toString()
	{
		String str = "";
		for (int v=0; v<numVertices; v++)
		{
			str += vertices[v].toString();
		}
		return str;
	}

	public void addVertex(Vertex v)
	{
		if (numVertices < maxVertices)
		{
			vertices[numVertices] = new Vertex(v);
			numVertices++;
		}
	}

	public void addVertex(double x, double y, double z)
	{
		if (numVertices < maxVertices)
		{
			vertices[numVertices] = new Vertex(x,y,z);
			numVertices++;
		}
	}


	public void show(Graphics g, int xpos, int ypos)
	{
		for (int v=0; v<numVertices; v++)
		{
			int x = xpos + (int) vertices[v].x;
			int y = ypos + (int) vertices[v].y;
			g.drawLine(x, y, x, y);
		}
	}
 }
